--[[

Version 0.1 - Initial framework completed //wowace svn

Author : Auldare of EU Khadgar 
	
--]]

local L = LibStub("AceLocale-3.0"):GetLocale("AspectInspect")
local AceAddon = LibStub("AceAddon-3.0")
local media = LibStub:GetLibrary("LibSharedMedia-3.0");
AspectInspect = AceAddon:NewAddon("AspectInspect", "AceConsole-3.0", "AceEvent-3.0")
local REVISION = tonumber(("$Revision: 19 $"):match("%d+"))

AspectInspect.textures = {}
AspectInspect.borders = {}
AspectInspect.fonts = {}
AspectInspect.sounds = {}
AspectInspect.frameBackdrop ={
		bgFile = "Interface/Tooltips/UI-Tooltip-Background",
		--edgeFile = "Interface/Tooltips/UI-Tooltip-Border",
		tile = false, tileSize = 0, edgeSize = 12,
		insets = { left = 0, right = 0, top = 0, bottom = 0 }
	}

local playerName=UnitName("player");

-------------------
-- Config details
-------------------

AspectInspect.defaults = {
	char = {
		message = "Welcome Home!",
		relativeTo = "UIParent",
		relativePoint = "CENTER",
		point = "CENTER",
		texture = "Blizzard",
		msgfont = "Friz Quadrata TT",
		msgfontsize = 24,
		msgfonteffect = "none",
		border = "None",
		barborder = "Blizzard Tooltip",
		xOffset = 0,
		yOffset = 0,
		fWidth = 300,
		fHeight = 175,
		scale = 1,
		debug = false,
	}
}

-----------------------------------------
-- Initialisation & Startup Routines
-----------------------------------------

function AspectInspect:OnInitialize()
	local AceConfigReg = LibStub("AceConfigRegistry-3.0")
	local AceConfigDialog = LibStub("AceConfigDialog-3.0")

	self.db = LibStub("AceDB-3.0"):New("AspectInspectDBPC", AspectInspect.defaults, "char")
	LibStub("AceConfig-3.0"):RegisterOptionsTable("AspectInspect", self:GetOptions(), {"AspectInspect", "ai"} )
	media.RegisterCallback(self, "LibSharedMedia_Registered")
	
	-- Add the options to blizzard frame (add them backwards so they show up in the proper order
	self.optionsFrame = AceConfigDialog:AddToBlizOptions("AspectInspect","AspectInspect")
	self.optionsFrame[L["About"]] = LibStub("LibAboutPanel").new("AspectInspect", "AspectInspect")
	self.db:RegisterDefaults(self.defaults)
	local version = GetAddOnMetadata("AspectInspect","Version")
	self.version = ("AspectInspect v%s (r%s)"):format(version, REVISION)
	self:Print(self.version.." Loaded.")
	self:Createaspectframe()
end

function AspectInspect:OnDisable()
    -- Called when the addon is disabled
end

function AspectInspect:OnEnable()
	self:LibSharedMedia_Registered()
	self:RegisterEvent("PLAYER_ENTERING_WORLD")
	self:RegisterEvent("UPDATE_BINDINGS")
	self:RegisterEvent("UNIT_AURA")
end

function AspectInspect:LibSharedMedia_Registered()
	for k, v in pairs(media:List("statusbar")) do
		self.textures[v] = v
	end
	for k, v in pairs(media:List("border")) do
		self.borders[v] = v
	end
	for k, v in pairs(media:List("font")) do
		self.fonts[v] = v
	end
	for k, v in pairs(media:List("sound")) do
		self.sounds[v] = v
	end
end

----------------------
-- Event Routines
----------------------

function AspectInspect:PLAYER_ENTERING_WORLD()
	self:SetFrameColor()
	-- does stuff when player zones
end

function AspectInspect:UPDATE_BINDINGS()
--~ 	self:UpdateBindings()
end

function AspectInspect:UNIT_AURA()
	if arg1 == "player" then
	self:SetFrameColor()
	end
end

function AspectInspect:SetFrameColor()
		local aspectenabled,aspectname = self:CheckForAspect(L["Aspect"])
		if aspectenabled then
			self:Print(aspectname.." "..L["yes"])
			if aspectname == L["AspectHawk"] then
				self.aspectframe:SetBackdropColor(0.2,0.2,0.8,0.20)
			elseif aspectname == L["AspectMonkey"] then
				self.aspectframe:SetBackdropColor(0.1,0.1,0.1,0.20)
			elseif aspectname == L["AspectDragonhawk"] then
				self.aspectframe:SetBackdropColor(0.8,0.2,0.8,0.20)
			elseif aspectname == L["AspectBeast"] then
				self.aspectframe:SetBackdropColor(0.9,0.1,0.1,0.20)
			elseif aspectname == L["AspectCheetah"] then
				self.aspectframe:SetBackdropColor(0.9,0.9,0,0.20)
			elseif aspectname == L["AspectPack"] then
				self.aspectframe:SetBackdropColor(0.9,0.9,0.9,0.20)
			elseif aspectname == L["AspectWild"] then
				self.aspectframe:SetBackdropColor(0.1,0.8,0.1,0.20)
			elseif aspectname == L["AspectViper"] then
				self.aspectframe:SetBackdropColor(0.1,0.9,0.8,0.20)
	
			end
		else
			self:Print(L["noaspect"])
			self.aspectframe:SetBackdropColor(0.6,0.6,0.6,0.75)
		end
end

function AspectInspect:CheckForAspect(pattern)
	local index = 1
	while UnitBuff("player", index) do
		local name, _, _, count, _, _, _, isMine = UnitBuff("player", index)
		self:DebugPrint("Found buff "..name.." checking for "..pattern)
		if strmatch(name,pattern) and isMine then -- don't return true on finding another player's aspect
			return true, name
		end
		index = index + 1
	end
	return false
end

function AspectInspect:DebugPrint(msg)
	if self.db.char.debug then
		self:Print(msg)
	end
end

function AspectInspect:Createaspectframe()
	self.aspectframe=CreateFrame("Frame",nil,UIParent)
	self.aspectframe:SetHeight(200)
	self.aspectframe:SetWidth(200)
	self.aspectframe:SetFrameStrata("BACKGROUND")
	self.aspectframe:SetScale(1)
	self.aspectframe:SetBackdrop(AspectInspect.frameBackdrop)
	self.aspectframe:SetBackdropColor(0.6,0.6,0.6,0.75)
	self.aspectframe:SetPoint("CENTER",UIParent,"CENTER",0,0)
	self.aspectframe:Show()
end